@@ -23,10 +23,10 @@
 
 #include <QDBusPendingReply>
 
-#include <KLocale>
+#include <KLocalizedString>
 #include <KMessageBox>
 #include <kdeversion.h>
-#include <KDebug>
+#include <QDebug>
 
 #include <ModemManager/ModemManager.h>
 #include <ModemManagerQt/manager.h>
@@ -87,7 +87,7 @@ void ModemMonitor::modemAdded(const QString & udi)
 void ModemMonitor::requestPin(MMModemLock lock)
 {
     Q_D(ModemMonitor);
-    kDebug() << "unlockRequired == " << lock;
+    qDebug() << "unlockRequired == " << lock;
     // Handle just SIM-PIN and SIM-PUK, because some other types may cause problems and they are not also handled by nm-applet
     if (lock == MM_MODEM_LOCK_NONE || lock == MM_MODEM_LOCK_UNKNOWN || (lock != MM_MODEM_LOCK_SIM_PIN && lock != MM_MODEM_LOCK_SIM_PUK)) {
         return;
@@ -99,7 +99,7 @@ void ModemMonitor::requestPin(MMModemLock lock)
     }
 
     if (d->dialog) {
-        kDebug() << "PinDialog already running";
+        qDebug() << "PinDialog already running";
         return;
     }
 
@@ -139,7 +139,7 @@ void ModemMonitor::requestPin(MMModemLock lock)
         goto OUT;
     }
 
-    kDebug() << "Sending unlock code";
+    qDebug() << "Sending unlock code";
 
     {
         ModemManager::Sim::Ptr sim;
