@@ -220,6 +220,8 @@ void NetworkModel::initializeSignals(const NetworkManager::Device::Ptr& device)
             SLOT(ipConfigChanged()), Qt::UniqueConnection);
     connect(device.data(), SIGNAL(ipV6ConfigChanged()),
             SLOT(ipConfigChanged()), Qt::UniqueConnection);
+    connect(device.data(), SIGNAL(ipInterfaceChanged()),
+            SLOT(ipInterfaceChanged()));
     connect(device.data(), SIGNAL(stateChanged(NetworkManager::Device::State,NetworkManager::Device::State,NetworkManager::Device::StateChangeReason)),
             SLOT(deviceStateChanged(NetworkManager::Device::State,NetworkManager::Device::State,NetworkManager::Device::StateChangeReason)), Qt::UniqueConnection);
 
@@ -363,9 +365,11 @@ void NetworkModel::addAvailableConnection(const QString& connection, const Netwo
             }
 
             NetworkManager::WirelessDevice::Ptr wifiDevice = device.objectCast<NetworkManager::WirelessDevice>();
-            NetworkManager::WirelessNetwork::Ptr wifiNetwork = wifiDevice->findNetwork(item->ssid());
-            if (wifiNetwork) {
-                updateFromWirelessNetwork(item, wifiNetwork);
+            if (wifiDevice) {
+                NetworkManager::WirelessNetwork::Ptr wifiNetwork = wifiDevice->findNetwork(item->ssid());
+                if (wifiNetwork) {
+                    updateFromWirelessNetwork(item, wifiNetwork);
+                }
             }
         }
 
@@ -876,7 +880,7 @@ void NetworkModel::gsmNetworkAccessTechnologyChanged(ModemManager::Modem::Access
                         ModemManager::Modem::Ptr modemNetwork = modem->interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
                         if (modemNetwork && modemNetwork->device() == gsmNetwork->device()) {
                             // TODO store access technology internally?
-                            foreach (NetworkModelItem * item, m_list.returnItems(NetworkItemsList::Device, modem->uni())) {
+                            foreach (NetworkModelItem * item, m_list.returnItems(NetworkItemsList::Device, dev->uni())) {
                                 updateItem(item);
                             }
                         }
@@ -898,7 +902,7 @@ void NetworkModel::gsmNetworkCurrentModesChanged()
                     if (modem->hasInterface(ModemManager::ModemDevice::ModemInterface)) {
                         ModemManager::Modem::Ptr modemNetwork = modem->interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
                         if (modemNetwork && modemNetwork->device() == gsmNetwork->device()) {
-                            foreach (NetworkModelItem * item, m_list.returnItems(NetworkItemsList::Device, modem->uni())) {
+                            foreach (NetworkModelItem * item, m_list.returnItems(NetworkItemsList::Device, dev->uni())) {
                                 updateItem(item);
                             }
                         }
@@ -920,7 +924,7 @@ void NetworkModel::gsmNetworkSignalQualityChanged(uint signal)
                     if (modem->hasInterface(ModemManager::ModemDevice::ModemInterface)) {
                         ModemManager::Modem::Ptr modemNetwork = modem->interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
                         if (modemNetwork && modemNetwork->device() == gsmNetwork->device()) {
-                            foreach (NetworkModelItem * item, m_list.returnItems(NetworkItemsList::Device, modem->uni())) {
+                            foreach (NetworkModelItem * item, m_list.returnItems(NetworkItemsList::Device, dev->uni())) {
                                 item->setSignal(signal);
                                 updateItem(item);
                             }
@@ -931,6 +935,7 @@ void NetworkModel::gsmNetworkSignalQualityChanged(uint signal)
         }
     }
 }
+
 #endif
 
 void NetworkModel::ipConfigChanged()
@@ -945,6 +950,20 @@ void NetworkModel::ipConfigChanged()
     }
 }
 
+void NetworkModel::ipInterfaceChanged()
+{
+    NetworkManager::Device * device = qobject_cast<NetworkManager::Device*>(sender());
+    if (device) {
+        foreach (NetworkModelItem * item, m_list.returnItems(NetworkItemsList::Device, device->uni())) {
+            if (device->ipInterfaceName().isEmpty()) {
+                item->setDeviceName(device->interfaceName());
+            } else {
+                item->setDeviceName(device->ipInterfaceName());
+            }
+        }
+    }
+}
+
 void NetworkModel::statusChanged(NetworkManager::Status status)
 {
     Q_UNUSED(status);
