@@ -25,6 +25,7 @@
 
 #include <QStandardPaths>
 #include <QFile>
+#include <QUrl>
 
 #include <KPluginFactory>
 #include <KSharedConfig>
@@ -146,7 +147,7 @@ NMVariantMapMap VpncUiPlugin::importConnectionSettings(const QString &fileName)
     KConfigGroup cg(config, "main");   // Keys&Values are stored under [main]
     if (cg.exists()) {
         // Setup cisco-decrypt binary to decrypt the passwords
-        const QString ciscoDecryptBinary = QStandardPaths::findExecutable("cisco-decrypt", QStringList() << QFile::decodeName(qgetenv("PATH")) << "/usr/lib/vpnc");
+        const QString ciscoDecryptBinary = QStandardPaths::findExecutable("cisco-decrypt");
         if (ciscoDecryptBinary.isEmpty()) {
             mErrorMessage = i18n("Needed executable cisco-decrypt could not be found.");
             return result;
@@ -280,7 +281,12 @@ NMVariantMapMap VpncUiPlugin::importConnectionSettings(const QString &fileName)
         setting.setSecrets(secretData);
 
         QVariantMap conn;
-        conn.insert("id", decrPlugin->readStringKeyValue(cg,"Description"));
+        if (decrPlugin->readStringKeyValue(cg,"Description").isEmpty()) {
+            QUrl name = fileName;
+            conn.insert("id", name.fileName().remove(QLatin1String(".pcf"), Qt::CaseInsensitive));
+        } else {
+            conn.insert("id", decrPlugin->readStringKeyValue(cg,"Description"));
+        }
         conn.insert("type", "vpn");
         result.insert("connection", conn);
 
